@@ -15,10 +15,6 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#if !defined (__EPHY_EPIPHANY_H_INSIDE__) && !defined (EPIPHANY_COMPILATION)
-#error "Only <epiphany/epiphany.h> can be included directly."
-#endif
-
 #ifndef WINDOW_COMMANDS_H
 #define WINDOW_COMMANDS_H
 
@@ -36,8 +32,6 @@ void window_cmd_go_location               (GtkAction  *action,
                                            EphyWindow *window);
 void window_cmd_view_reload               (GtkAction  *action,
                                            EphyWindow *window);
-void window_cmd_new                       (GtkAction  *action,
-                                           EphyWindow *window);
 void window_cmd_file_bookmark_page        (GtkAction  *action,
                                            EphyWindow *window);
 void window_cmd_file_open                 (GtkAction  *action,
@@ -72,6 +66,8 @@ void window_cmd_edit_find_next            (GtkAction  *action,
                                            EphyWindow *window);
 void window_cmd_edit_find_prev            (GtkAction  *action,
                                            EphyWindow *window);
+void window_cmd_view_encoding             (GtkAction  *action,
+                                           EphyWindow *window);
 void window_cmd_view_fullscreen           (GtkAction  *action,
                                            EphyWindow *window);
 void window_cmd_view_zoom_in              (GtkAction  *action,
